@@ -19,13 +19,18 @@ import argparse
 import logging
 import os
 import sys
+import sysconfig
 
 import appdirs
 
+from bandit.core import config as b_config
+from bandit.core import constants
 from bandit.core import manager as b_manager
 from bandit.core import utils
 
-BASE_CONFIG = '/bandit.yaml'
+
+BASE_CONFIG = 'bandit.yaml'
+logger = logging.getLogger()
 
 
 def _init_logger(debug=False, log_format=None):
@@ -34,6 +39,7 @@ def _init_logger(debug=False, log_format=None):
     :param debug: Whether to enable debug mode
     :return: An instantiated logging instance
     '''
+    logger.handlers = []
     log_level = logging.INFO
     if debug:
         log_level = logging.DEBUG
@@ -46,13 +52,11 @@ def _init_logger(debug=False, log_format=None):
 
     logging.captureWarnings(True)
 
-    logger = logging.getLogger()
     logger.setLevel(log_level)
     handler = logging.StreamHandler(sys.stdout)
     handler.setFormatter(logging.Formatter(log_format_string))
     logger.addHandler(handler)
     logger.debug("logging initialized")
-    return logger
 
 
 def _init_extensions():
@@ -60,13 +64,25 @@ def _init_extensions():
     return ext_loader.MANAGER
 
 
+def _running_under_virtualenv():
+    if hasattr(sys, 'real_prefix'):
+        return True
+    elif sys.prefix != getattr(sys, 'base_prefix', sys.prefix):
+        return True
+
+
 def _find_config():
     # prefer config file in the following order:
     # 1) current directory, 2) user home directory, 3) bundled config
     config_dirs = (
         ['.'] + [appdirs.user_config_dir("bandit")] +
         appdirs.site_config_dir("bandit", multipath=True).split(':'))
-    config_locations = [s + BASE_CONFIG for s in config_dirs]
+    if _running_under_virtualenv():
+        config_dirs.append(os.path.join(sys.prefix, 'etc', 'bandit'))
+        config_dirs.append(
+            os.path.join(sysconfig.get_paths().get('purelib', ''),
+                         'bandit', 'config'))
+    config_locations = [os.path.join(s, BASE_CONFIG) for s in config_dirs]
 
     # pip on Mac installs to the following path, but appdirs expects to
     # follow Mac's BPFileSystem spec which doesn't include this path so
@@ -86,7 +102,7 @@ def _find_config():
 def main():
     # bring our logging stuff up as early as possible
     debug = ('-d' in sys.argv or '--debug' in sys.argv)
-    logger = _init_logger(debug)
+    _init_logger(debug)
     # By default path would be /etx/xdg/bandit, we want system paths
     os.environ['XDG_CONFIG_DIRS'] = '/etc:/usr/local/etc'
     extension_mgr = _init_extensions()
@@ -111,7 +127,7 @@ def main():
     )
     parser.add_argument(
         '-n', '--number', dest='context_lines',
-        action='store', default=-1, type=int,
+        action='store', default=3, type=int,
         help='max number of code lines to display for each issue identified'
     )
     parser.add_argument(
@@ -171,8 +187,19 @@ def main():
             logger.error(e)
             sys.exit(2)
 
-    b_mgr = b_manager.BanditManager(config_file, args.agg_type,
-                                    args.debug, profile_name=args.profile,
+    try:
+        b_conf = b_config.BanditConfig(config_file)
+    except (utils.ConfigFileUnopenable, utils.ConfigFileInvalidYaml) as e:
+        logger.error('%s', e)
+        sys.exit(2)
+
+    # if the log format string was set in the options, reinitialize
+    if b_conf.get_option('log_format'):
+        log_format = b_conf.get_option('log_format')
+        _init_logger(debug, log_format=log_format)
+
+    b_mgr = b_manager.BanditManager(b_conf, args.agg_type, args.debug,
+                                    profile_name=args.profile,
                                     verbose=args.verbose)
 
     if args.output_format != "json":
@@ -202,16 +229,19 @@ def main():
     # initiate execution of tests within Bandit Manager
     b_mgr.run_tests()
     if args.debug:
-        b_mgr.output_metaast()
+        print(b_mgr.b_ma)
 
     # trigger output of results by Bandit Manager
-    b_mgr.output_results(args.context_lines, args.severity - 1,
-                         args.confidence - 1, args.output_file,
+    sev_level = constants.RANKING[args.severity - 1]
+    conf_level = constants.RANKING[args.confidence - 1]
+    b_mgr.output_results(args.context_lines,
+                         sev_level,
+                         conf_level,
+                         args.output_file,
                          args.output_format)
 
     # return an exit code of 1 if there are results, 0 otherwise
-    if b_mgr.results_count(sev_filter=args.severity - 1,
-                           conf_filter=args.confidence - 1) > 0:
+    if b_mgr.results_count(sev_filter=sev_level, conf_filter=conf_level) > 0:
         sys.exit(1)
     else:
         sys.exit(0)
