@@ -19,107 +19,118 @@ import logging
 import os
 import sys
 
-import config as b_config
-import meta_ast as b_meta_ast
-import node_visitor as b_node_visitor
-import result_store as b_result_store
-import test_set as b_test_set
+from bandit.core import constants as b_constants
+from bandit.core import extension_loader
+from bandit.core import meta_ast as b_meta_ast
+from bandit.core import node_visitor as b_node_visitor
+from bandit.core import test_set as b_test_set
+
+
+logger = logging.getLogger(__name__)
 
 
 class BanditManager():
 
     scope = []
 
-    def __init__(self, config_file, agg_type, debug=False, profile_name=None):
+    def __init__(self, config, agg_type, debug=False, verbose=False,
+                 profile_name=None):
         '''Get logger, config, AST handler, and result store ready
 
-        :param config_file: A file to read config from
+        :param config: config options object
+        :type config: bandit.core.BanditConfig
+        :param agg_type: aggregation type
         :param debug: Whether to show debug messsages or not
+        :param verbose: Whether to show verbose output
         :param profile_name: Optional name of profile to use (from cmd line)
         :return:
         '''
         self.debug = debug
-        self.logger = self._init_logger(debug)
-        self.b_conf = b_config.BanditConfig(self.logger, config_file)
+        self.verbose = verbose
+        self.b_conf = config
         self.files_list = []
         self.excluded_files = []
-
-        # if the log format string was set in the options, reinitialize
-        if self.b_conf.get_option('log_format'):
-            # have to clear old handler
-            self.logger.handlers = []
-            log_format = self.b_conf.get_option('log_format')
-            self.logger = self._init_logger(debug, log_format=log_format)
-
-        self.b_ma = b_meta_ast.BanditMetaAst(self.logger)
-        self.b_rs = b_result_store.BanditResultStore(self.logger, self.b_conf,
-                                                     agg_type)
+        self.b_ma = b_meta_ast.BanditMetaAst()
+        self.skipped = []
+        self.results = []
+        self.agg_type = agg_type
 
         # if the profile name was specified, try to find it in the config
         if profile_name:
             if profile_name in self.b_conf.config['profiles']:
                 profile = self.b_conf.config['profiles'][profile_name]
-                self.logger.debug(
+                logger.debug(
                     "read in profile '%s': %s",
                     profile_name, profile
                 )
             else:
-                self.logger.error(
-                    'unable to find profile (%s) in config file: '
-                    '%s' % (profile_name, config_file)
-                )
-                sys.exit(2)
+                raise RuntimeError('unable to find profile (%s) in config'
+                                   'file: %s' % (profile_name,
+                                                 self.b_conf.config_file))
         else:
             profile = None
 
-        self.b_ts = b_test_set.BanditTestSet(self.logger, config=self.b_conf,
+        self.b_ts = b_test_set.BanditTestSet(config=self.b_conf,
                                              profile=profile)
 
         # set the increment of after how many files to show progress
         self.progress = self.b_conf.get_setting('progress')
         self.scores = []
 
-    @property
-    def get_logger(self):
-        return self.logger
+    def get_issue_list(self):
+        return self.results
 
     @property
-    def get_resultstore(self):
-        return self.b_rs
+    def has_tests(self):
+        return self.b_ts.has_tests
 
-    @property
-    def results_count(self):
+    def results_count(self, sev_filter=b_constants.LOW,
+                      conf_filter=b_constants.LOW):
         '''Return the count of results
 
+        :param sev_filter: Severity level to filter lower
+        :param conf_filter: Confidence level to filter
         :return: Number of results in the set
         '''
-        return self.b_rs.count
+        return sum(i.filter(sev_filter, conf_filter) for i in self.results)
 
-    def output_results(self, lines, level, output_filename, output_format):
+    def output_results(self, lines, sev_level, conf_level, output_filename,
+                       output_format):
         '''Outputs results from the result store
 
         :param lines: How many surrounding lines to show per result
-        :param level: Which levels to show (info, warning, error)
+        :param sev_level: Which severity levels to show (LOW, MEDIUM, HIGH)
+        :param conf_level: Which confidence levels to show (LOW, MEDIUM, HIGH)
         :param output_filename: File to store results
-        :param output_format: output format, either 'json' or 'txt'
+        :param output_format: output format, 'csv', 'json', 'txt', 'xml', or
+            'html'
         :return: -
         '''
+        try:
+            formatters_mgr = extension_loader.MANAGER.formatters_mgr
+            try:
+                formatter = formatters_mgr[output_format]
+            except KeyError:  # Unrecognized format, so use text instead
+                formatter = formatters_mgr['txt']
+                output_format = 'txt'
 
-        self.b_rs.report(
-            self.files_list, self.scores,
-            excluded_files=self.excluded_files, lines=lines,
-            level=level, output_filename=output_filename,
-            output_format=output_format
-        )
+            if output_format == 'csv':
+                lines = 1
+            elif formatter.name == 'txt' and output_filename:
+                output_format = 'plain'
 
-    def output_metaast(self):
-        '''Outputs all the nodes from the Meta AST.'''
-        self.b_ma.report()
+            report_func = formatter.plugin
+            report_func(self, filename=output_filename,
+                        sev_level=sev_level, conf_level=conf_level,
+                        lines=lines, out_format=output_format)
+
+        except IOError:
+            print("Unable to write to file: %s" % output_filename)
 
     def discover_files(self, targets, recursive=False):
         '''Add tests directly and from a directory to the test set
 
-        :param scope: The command line list of files and directories
+        :param targets: The command line list of files and directories
         :param recursive: True/False - whether to add all files from dirs
         :return:
         '''
@@ -129,7 +140,7 @@ class BanditManager():
         excluded_files = set()
 
         excluded_path_strings = self.b_conf.get_option('exclude_dirs') or []
-        included_globs = self.b_conf.get_option('include') or '*.py'
+        included_globs = self.b_conf.get_option('include') or ['*.py']
 
         # build list of files we will analyze
         for fname in targets:
@@ -144,8 +155,8 @@ class BanditManager():
                     files_list.update(new_files)
                     excluded_files.update(newly_excluded)
                 else:
-                    self.logger.warn("Skipping directory (%s), use -r flag to "
-                                     "scan contents" % fname)
+                    logger.warn("Skipping directory (%s), use -r flag to "
+                                "scan contents", fname)
 
             else:
                 # if the user explicitly mentions a file on command line,
@@ -190,7 +201,7 @@ class BanditManager():
         new_files_list = list(self.files_list)
 
         for count, fname in enumerate(self.files_list):
-            self.logger.debug("working on file : %s" % fname)
+            logger.debug("working on file : %s", fname)
 
             if len(self.files_list) > self.progress:
                 # is it time to update the progress indicator?
@@ -202,18 +213,16 @@ class BanditManager():
                     try:
                         # parse the current file
                         score = self._execute_ast_visitor(
-                            fname, fdata, self.b_ma,
-                            self.b_rs, self.b_ts
-                        )
+                            fname, fdata, self.b_ma, self.b_ts)
                         self.scores.append(score)
                     except KeyboardInterrupt as e:
                         sys.exit(2)
             except IOError as e:
-                self.b_rs.skip(fname, e.strerror)
+                self.skipped.append((fname, e.strerror))
                 new_files_list.remove(fname)
             except SyntaxError as e:
-                self.b_rs.skip(fname,
-                               "syntax error while parsing AST from file")
+                self.skipped.append(
+                    (fname, "syntax error while parsing AST from file"))
                 new_files_list.remove(fname)
 
         if len(self.files_list) > self.progress:
@@ -223,50 +232,26 @@ class BanditManager():
         # reflect any files which may have been skipped
         self.files_list = new_files_list
 
-    def _execute_ast_visitor(self, fname, fdata, b_ma, b_rs, b_ts):
+    def _execute_ast_visitor(self, fname, fdata, b_ma, b_ts):
         '''Execute AST parse on each file
 
         :param fname: The name of the file being parsed
         :param fdata: The file data of the file being parsed
         :param b_ma: The class Meta AST instance
-        :param b_rs: The class result store instance
         :param b_ts: The class test set instance
         :return: The accumulated test score
         '''
         score = []
         if fdata is not None:
             res = b_node_visitor.BanditNodeVisitor(
-                fname, self.logger, self.b_conf, b_ma, b_rs, b_ts, self.debug
+                fname, self.b_conf, b_ma, b_ts, self.debug
             )
             score = res.process(fdata)
+            self.results.extend(res.tester.results)
         return score
 
-    def _init_logger(self, debug=False, log_format=None):
-        '''Initialize the logger
 
-        :param debug: Whether to enable debug mode
-        :return: An instantiated logging instance
-        '''
-        log_level = logging.INFO
-        if debug:
-            log_level = logging.DEBUG
-
-        if not log_format:
-            # default log format
-            log_format_string = '[%(module)s]\t%(levelname)s\t%(message)s'
-        else:
-            log_format_string = log_format
-
-        logger = logging.getLogger()
-        logger.setLevel(log_level)
-        handler = logging.StreamHandler(sys.stdout)
-        handler.setFormatter(logging.Formatter(log_format_string))
-        logger.addHandler(handler)
-        logger.debug("logging initialized")
-        return logger
-
-
-def _get_files_from_dir(files_dir, included_globs='*.py',
+def _get_files_from_dir(files_dir, included_globs=['*.py'],
                         excluded_path_strings=None):
     if not excluded_path_strings:
         excluded_path_strings = []
